@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION );
 
-$VERSION = '0.38_01';
+$VERSION = '0.33';
 
 use DateTime;
 use HTTP::Date qw();
@@ -26,6 +26,7 @@ sub parse_datetime
     my ($self, $str, $zone) = @_;
     local $_;
     die "No input string!" unless defined $str;
+    #warn "In: [$str]\n";
 
     # fast exit for strictly conforming string
     if ($str =~ /^
@@ -47,14 +48,16 @@ sub parse_datetime
     }
 
     my %d = $self->_parse_date($str);
+    die "Unable to parse date [$str]\n" unless keys %d;
 
     unless (defined $d{time_zone})
     {
-	$d{time_zone} = defined $zone ? $zone : 'floating';
+	$d{time_zone} = defined $zone ? $zone : 'local';
     }
 
+    $d{second} ||= 0;
     my $frac = $d{second}; $frac -= ($d{second} = int($frac));
-    my $nano = 100_000_000 * $frac; $d{nanosecond} = int($nano);
+    my $nano = 100_000_000 * $frac; $d{nanosecond} = $nano;
     return DateTime->new( %d );
 }
 
@@ -105,7 +108,7 @@ __END__
 
 =head1 NAME
 
-DateTime::Format::HTTP - Date conversion routines
+DateTime::Format::HTTP - date conversion routines
 
 =head1 SYNOPSIS
 
@@ -124,7 +127,7 @@ HTTP protocol (and then some more).
 
 =head2 parse_datetime( $str [, $zone] )
 
-The parse_datetime() function converts a string to machine time. It throws
+The str2time() function converts a string to machine time. It throws
 an error if the format of $str is unrecognized, or the time is outside
 the representable range. The time formats recognized are listed below.
 
@@ -132,7 +135,7 @@ The function also takes an optional second argument that specifies the
 default time zone to use when converting the date. This parameter is
 ignored if the zone is found in the date string itself. If this
 parameter is missing, and the date string format does not contain
-any zone specification, then the floating time zone is used.
+any zone specification, then the local time zone is assumed.
 
 The zone should be one that is recognized by L<DateTime::TimeZone>.
 
@@ -201,46 +204,27 @@ recommended that you use C<format_isoz> or C<format_datetime> instead
 Same as format_iso(), but returns a "YYYY-MM-DD hh:mm:ssZ"-formatted
 string representing Universal Time.
 
+=head1 LICENSE AND COPYRIGHT
+
+Copyright E<copy> Iain Truskett, 2003. All rights reserved.
+Sections of the documentation E<copy> Gisle Aas, 1995-1999.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+The full text of the licenses can be found in the F<Artistic> and
+F<COPYING> files included with this module, or if you are using Perl
+5.8.1 or later, they can be found under L<perlartistic> and L<perlgpl>.
+
 =head1 THANKS
 
 Gisle Aas (GAAS) for writing L<HTTP::Date>.
 
-Iain, for never quite finishing C<HTTP::Date::XS>.
-
-=head1 SUPPORT
-
-Support for this module is provided via the datetime@perl.org email
-list. See http://lists.perl.org/ for more details.
-
-Alternatively, log them via the CPAN RT system via the web or email:
-
-    http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DateTime%3A%3AFormat%3A%3AHTTP
-    bug-datetime-format-http@rt.cpan.org
-
-This makes it much easier for me to track things and thus means
-your problem is less likely to be neglected.
-
-=head1 LICENCE AND COPYRIGHT
-
-Copyright Iain Truskett, 2003. All rights reserved.
-Sections of the documentation Gisle Aas, 1995-1999.
-Changes since version 0.35 copyright David Rolsky, 2004.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.000 or,
-at your option, any later version of Perl 5 you may have available.
-
-The full text of the licences can be found in the F<Artistic> and
-F<COPYING> files included with this module, or in L<perlartistic> and
-L<perlgpl> as supplied with Perl 5.8.1 and later.
-
+Me, for never quite finishing C<HTTP::Date::XS>.
 
 =head1 AUTHOR
 
-Originally written by Iain Truskett <spoon@cpan.org>, who died on
-December 29, 2003.
-
-Maintained by Dave Rolsky <autarch@urth.org> and Christiaan Kras <ckras@cpan.org>
+Iain Truskett <spoon@cpan.org>
 
 =head1 SEE ALSO
 
